#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 annotated-wl-pprint
version:              0.7.0
visibility:           public
id:                   annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
key:                  annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
license:              BSD-3-Clause
maintainer:           david@davidchristiansen.dk
author:               Daan Leijen, David Raymond Christiansen
homepage:             https://github.com/david-christiansen/annotated-wl-pprint
synopsis:             The Wadler/Leijen Pretty Printer, with annotation support
description:
    This is a modified version of wl-pprint, which was based on Wadler'\''s
    paper "A Prettier  Printer".  See the haddocks for full info.  This
    version allows the library user to annotate the text with semantic
    information, which can later be rendered in a variety of ways.

category:             Text
abi:                  6ab820c38d66f1624a3e0621945b8024
exposed:              True
exposed-modules:      Text.PrettyPrint.Annotated.Leijen
import-dirs:          /usr/lib/ghc-9.6.6/site-local/annotated-wl-pprint-0.7.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/annotated-wl-pprint-0.7.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/annotated-wl-pprint-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-annotated-wl-pprint
hs-libraries:         HSannotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-annotated-wl-pprint/html/annotated-wl-pprint.haddock

haddock-html:         /usr/share/doc/haskell-annotated-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

